- x
The input data frame containing experimental design columns, target gene
E/Ct column pairs, and reference gene E/Ct column pairs. Reference gene
columns must be located at the end of the data frame. See "Input data
structure" in vignettes for details about data structure.
- numOfFactors
Integer. Number of experimental factor columns
(excluding rep and optional block).
- numberOfrefGenes
Integer. Number of reference genes. Each reference gene
must be represented by two columns (E and Ct).
- block
Character. Block column name or NULL. When a qPCR experiment
is done in multiple qPCR plates, variation resulting from the plates may
interfere with the actual amount of gene expression. One solution is to
conduct each plate as a randomized block so that at least one replicate of
each treatment and control is present on a plate. Block effect is usually
considered as random and its interaction with any main effect is not considered.
Note: This parameter is ignored if model is provided.
- alpha
Statistical level for comparisons (default: 0.05).
- p.adj
Method for p-value adjustment. See p.adjust.
- analyseAllTarget
Logical or character. If TRUE (default), all
detected target genes are analysed. Alternatively, a character vector
specifying the names (names of their Efficiency columns) of target genes
to be analysed.
- model
Optional model formula. If provided, this overrides the automatic formula (CRD or RCBD
based on block and numOfFactors). The formula uses
wDCt as the response variable.
For mixed models, random effects can be defined using lmer syntax
(e.g., "wDCt ~ Treatment + (1|Block)"). When using model,
the block and numOfFactors arguments are ignored for model
specification, but still used for data structure identification.
- modelBased_se
Logical. If TRUE (default), standard errors are
calculated from model-based residuals. If FALSE, standard errors are calculated directly from the observed
wDCt values within each treatment group according to the selected se.type.
For single factor data, both methods are the same. It is recommended to use modelBased_se = TRUE (default).
- set_missing_target_Ct_to_40
If TRUE, missing target gene Ct values become 40; if FALSE (default), they become NA.