Performs \(\Delta C_T\) analysis for target genes by applying \(\Delta C_T\) method to each target gene. Target genes must be provided as paired efficiency (E) and Ct columns followed by the the reference gene(s) columns. See "Input data structure and column arrangement" in vignettes for details about data structure.
ANOVA_DCt(
x,
numOfFactors,
numberOfrefGenes,
block,
alpha = 0.05,
p.adj = "none",
analyseAllTarget = TRUE
)An object containing expression table, lm models, ANOVA tables, residuals, raw data and ANOVA table for each gene.
object$combinedResults
object$perGene$gene_name$ANOVA_T
object$perGene$gene_name$ANOVA_factorial
object$perGene$gene_name$lm_T
object$perGene$gene_name$lm_factorial
resid(object$perGene$gene_name$lm_T)
A data frame containing experimental design columns, target gene E/Ct column pairs, and reference gene E/Ct column pairs. Reference gene columns must be located at the end of the data frame.
Integer. Number of experimental factor columns
(excluding rep and optional block).
Integer. Number of reference genes. Each reference gene must be represented by two columns (E and Ct).
Character or NULL. Name of the blocking factor column.
When a qPCR experiment is done in multiple qPCR plates,
variation resulting from the plates may interfere with the actual amount of
gene expression. One solution is to conduct each plate as a randomized block
so that at least one replicate of each treatment and control is present
on a plate. Block effect is usually considered as random and its interaction
with any main effect is not considered.
statistical level for comparisons
Method for p-value adjustment. See p.adjust.
Logical or character.
If TRUE (default), all detected target genes are analysed.
Alternatively, a character vector specifying the names (names of their Efficiency columns) of target genes
to be analysed.
data <- read.csv(system.file("extdata", "data_3factor.csv", package = "rtpcr"))
res <- ANOVA_DCt(
data,
numOfFactors = 3,
numberOfrefGenes = 1,
block = NULL)
Run the code above in your browser using DataLab