- x
The input data frame containing experimental design columns, replicates (integer), target gene
E/Ct column pairs, and reference gene E/Ct column pairs. Reference gene
columns must be located at the right end of the data frame. See "Input data
structure" in vignettes for details about data structure.
- numOfFactors
Integer. Number of experimental factor columns
(excluding rep and optional block).
- numberOfrefGenes
Integer. Number of reference genes.
- specs
Example: "A", "A|B" or "A|B*C" if A, B and C are name of factor columns in the input data
The first name (here A) is the factor for which the relative expression is analysed.
- block
Character. Block column name or NULL.
When a qPCR experiment is done in multiple qPCR plates,
variation resulting from the plates may interfere with the actual amount of
gene expression. One solution is to conduct each plate as a randomized block
so that at least one replicate of each treatment and control is present
on a plate. Block effect is usually considered as random and its interaction
with any main effect is not considered.
- calibratorLevel
NULL or one of the levels of the first selected factor in specs argument. If NULL the first level of that factor is used as calibrator.
Optional character vector specifying the order of levels for the main factor.
If NULL, the first observed level is used as the calibrator.
If provided, the first element of the vector is used as the calibrator level.
- p.adj
Method for p-value adjustment. See p.adjust.
- analyseAllTarget
Logical or character.
If TRUE (default), all target genes are analysed.
Alternatively, a character vector specifying the names (names of their Efficiency columns) of target genes
to be analysed.
- model
Optional model formula. If provided, this overrides the automatic formula (factorial CRD or RCBD
based on block and numOfFactors). The formula uses
wDCt as the response variable.
For mixed models, random effects can be defined using lmer syntax
(e.g., "wDCt ~ Treatment + (1 | id)"). When using model,
the block and numOfFactors arguments are ignored for model
specification, but still used for data structure identification.
for fixed effects only, the "lm" (ordinary least squares) is used.
"lmer" is used for mixed effects models
(requires the lmerTest package). If a custom formula is provided with
random effects, the function will use lmerTest::lmer(); otherwise
it will use stats::lm(). Note that emmeans supports both
model types and will use appropriate degrees of freedom methods (Satterthwaite by default).
- set_missing_target_Ct_to_40
If TRUE, missing target gene Ct values become 40; if FALSE (default), they become NA.
- se.type
Character string specifying how standard error is calculated.
One of "paired.group", "two.group", or "single.group".
"paired.group" computes SE from paired differences (used when a random
id effect is present), "two.group" uses the unpaired two-group
t-test standard error against the reference level, and "single.group"
computes SE within each level using a one-group t-test.
- modelBased_se
Logical. If TRUE (default), standard errors are
calculated from model-based residuals. If FALSE, standard errors are calculated directly from the observed
wDCt values within each treatment group according to the selected se.type.
For single factor data, both methods are the same. It is recommended to use modelBased_se = TRUE (default).
- ...
Additional arguments. Included for backward compatibility with deprecated mainFactor.column.