Learn R Programming

rtpcr (version 2.1.1)

REPEATED_DDCt: Delta Delta Ct ANOVA analysis on repeated measure data

Description

REPEATED_DDCt function performs \(\Delta \Delta C_T\) method analysis of observations repeatedly taken over different time courses. Data may be obtained over time from a uni- or multi-factorial experiment. Target genes must be provided as paired efficiency (E) and Ct columns followed by the E/Ct column pairs of reference genes.

Usage

REPEATED_DDCt(
  x,
  numOfFactors,
  numberOfrefGenes,
  repeatedFactor,
  calibratorLevel,
  block,
  p.adj = "none",
  plot = FALSE,
  analyseAllTarget = TRUE
)

Value

An object containing expression table, lm models, residuals, raw data and ANOVA table for each gene.

\(\Delta \Delta C_T\) combined expression table

object$Relative_Expression_table

ANOVA table

object$perGene$gene_name$ANOVA_table

lm ANOVA

object$perGene$gene_name$lm

Residuals

resid(object$perGene$gene_name$lm)

log2FC_Plot

object$perGene$gene_name$log2FC_Plot

RE_Plot

object$perGene$gene_name$RE_Plot

Arguments

x

input data frame in which the first column is id, followed by the factor column(s) which include at least time. The first level of time in data frame is used as calibrator or reference level. Additional factor(s) may also be present. Other columns are efficiency and Ct values of target and reference genes. In the id column, a unique number is assigned to each individual from which samples have been taken over time, for example see data_repeated_measure_1, all the three number 1 indicate one individual which has been sampled over three different time courses. See example data sets or refer vignettes, section "Input data structure" for details.

numOfFactors

Integer. Number of experimental factor columns (excluding optional block).

numberOfrefGenes

Integer. Number of reference genes. Each reference gene must be represented by two columns (E and Ct).

repeatedFactor

Character string specifying the factor for which fold changes are analysed (commonly "time").

calibratorLevel

A level of repeatedFactor to be used as the calibrator (reference level) which is the reference level or sample that all others are compared to. Examples are untreated or time 0.

block

Character or NULL. Name of the blocking factor column. When a qPCR experiment is done in multiple qPCR plates, variation resulting from the plates may interfere with the actual amount of gene expression. One solution is to conduct each plate as a randomized block so that at least one replicate of each treatment and control is present on a plate. Block effect is usually considered as random and its interaction with any main effect is not considered.

p.adj

Method for p-value adjustment. See p.adjust.

plot

Logical; if FALSE, plots are not produced.

analyseAllTarget

Logical or character. If TRUE (default), all detected target genes are analysed. Alternatively, a character vector specifying the names (names of their Efficiency columns) of target genes to be analysed.

Details

Column layout requirements for x:

  • Target gene columns: E/Ct column pairs located between design and reference columns

  • Reference gene columns: E/Ct column pairs located at the end

Examples

Run this code
data1 <- read.csv(system.file("extdata", "data_repeated_measure_1.csv", package = "rtpcr"))
REPEATED_DDCt(
  data1,
  numOfFactors = 1,
  numberOfrefGenes = 1,
  repeatedFactor = "time",
  calibratorLevel = "1",
  block = NULL)



data2 <- read.csv(system.file("extdata", "data_repeated_measure_2.csv", package = "rtpcr"))
REPEATED_DDCt(
  data2,
  numOfFactors = 2,
  numberOfrefGenes = 1,
  repeatedFactor = "time", 
  calibratorLevel = "1",
  block = NULL,
  p.adj = "none",
  plot = FALSE,
  analyseAllTarget = TRUE)

Run the code above in your browser using DataLab